{% extends "base.html" %} {% load i18n %} {% load staticfiles %} {% load wger_extras %} {% block title %}{% trans "Changelog" %}{% endblock %} {% block content %}

### 1.4

#### 2014-03-08

- Calendar view to more easily check workout logs
- Add "gym mode" with timer to log the workout while at the gym
- Add automatic email remainders for new workouts
- New iCal export to add workouts and schedules e.g. to google calendar
- New exercise overview, grouped by equipment
- Add possibility to write comments and rate the workout
- Simplify form for new exercises
- Alternative PDF export of workout without table for entering logs
- Unified way of specifying license of submitted content (exercises, etc.)

### 1.3

#### 2013-11-27

- New translations
  - Bulgarian (many thanks to Lyuboslav Petrov!)
  - Russian (many thanks to Inna!)
  - Spanish
- Mobile version of website
- Add images to the exercises
- Exercises now can list needed equipment (barbell, etc.)
- BMI calculator
- Daily calories calculator
- New management utility for languages
- Improved performance
- RESTful API

### 1.2

#### 2013-05-19

- Added scheduling option for workouts.
- Open all parts of website to all users, this is done by a custom middleware
- Regular users can submit exercises and ingredients to be included in the general list
- Add more 'human' units to ingredients like '1 cup' or '1 slice'
- Add nutritional values calculator on the ingredient detail page
- Several bugfixes
- Usability improvements

### 1.1.1

#### 2013-03-06

- Pin version of app django_browserid due to API changes in 0.8
- Fix issue with tabs on exercise overview due to API changes in JQuery

### 1.1

#### 2013-02-23

- Better navigation bar
- Added descriptions for the exercises (German)
- New workout logbook, to keep track of your improvements
- Import your weight logs from a spreadsheet (CSV-Import)
- Better filtering for weight chart
- Muscle overview with corresponding exercises
- Add guest accounts by generating a temporary user
- Description pages about the software
- Easier installation process

### 1.0.3

#### 2012-11-19

- Add option to copy (duplicate) workouts and nutritional plans
- Login without an account with [[https://login.persona.org/|mozilla's Persona]] (BrowserID)
- Better AJAX handling of the modal dialogs, less page reloads and redirects
- Expand the list of ingredients in German
- Add a pagination to ingredient list
- Improvements to user page:
  - Add a "reset password" link to the login page
  - Email is now user editable
- More natural lines in weight chart with cubic interpolation

### 1.0.2

#### 2012-11-02

- Bugfix release

### 1.0.1

#### 2012-11-02

- Fix issue with password change
- Small improvements to UI
- Categories editable/deletable from exercise overview page
- Exercise AJAX search groups by category
- More tests!
- Use generic views for editing, creating and deleting objects

### 1.0

#### 2012-10-16

Initial release.

- Workout manager
- PDF output for logging progress
- Initial data with the most popular exercises
- Simple weight chart
- Nutrition plan manager
- Simple PDF output
- Initial data with nutritional values from the USDA

{% endblock %}